
#ifdef GL_ES
precision mediump float;
#endif

varying vec4 v_fragmentColor;
varying vec2 v_texCoord;

//核心：计算函数，角度，uv,光带的x长度，间隔，开始时间，偏移，单次循环时间
float inFlash(float angle, vec2 uv, float xLength, float interval, float beginTime, float offX, float loopTime)
{
	//亮度值
	float brightness = 0.0;
   
	//倾斜角
	float angleInRad = 0.0174444 * angle;
	//float angleInRad = angle;
   
   float time = CC_Time[1];
	//当前时间
	float currentTime = time;

	//获取本次光照的起始时间
	float currentTimeInt = time / interval;
	currentTimeInt -= fract(currentTimeInt);//取整
	currentTimeInt *= interval;
   
	//获取本次光照的流逝时间 = 当前时间 - 起始时间
	float currentTimePassed = currentTime - currentTimeInt;
	if(currentTimePassed > beginTime)
	{
		//底部左边界和右边界
		float xBottomLeftBound = 0.0;
		float xBottomRightBound = 0.0;

		//此点边界
		float xPointLeftBound = 0.0;
		float xPointRightBound = 0.0;
	   
		float x0 = currentTimePassed - beginTime;
		x0 /= loopTime;

		//设置右边界
		xBottomRightBound = x0;
	   
		//设置左边界
		xBottomLeftBound = x0 - xLength;
	   
		//投影至x的长度 = y / tan(angle)
		float xProjL = 0.0;
		xProjL= (uv.y) / tan(angleInRad);

		//此点的左边界 = 底部左边界 - 投影至x的长度
		xPointLeftBound = xBottomLeftBound - xProjL;
		//此点的右边界 = 底部右边界 - 投影至x的长度
		xPointRightBound = xBottomRightBound - xProjL;
	   
		//边界加上一个偏移
		xPointLeftBound += offX;
		xPointRightBound += offX;
	   
		//如果该点在区域内
		if(uv.x > xPointLeftBound && uv.x < xPointRightBound)
		{
			//得到发光区域的中心点
			float midness = (xPointLeftBound + xPointRightBound) / 2.0;
		   
			//趋近中心点的程度，0表示位于边缘，1表示位于中心点
			float rate = (xLength - 2.0 * abs(uv.x - midness)) / (xLength);
			brightness = rate;
		}
	}
	brightness= max(brightness, 0.0);
   
	//返回颜色 = 纯白色 * 亮度
	vec4 col = vec4(1.0, 1.0, 1.0, 1.0) * brightness;
	return brightness;
}

void main() {
		vec4 texCol = texture2D(CC_Texture0, v_texCoord);
		
		float tmpBrightness = 0.0;
		     //角度，uv, 光带的x长度，间隔，开始时间，偏移，单次循环时间;
		tmpBrightness = inFlash(75.0, v_texCoord, 0.25, 5.0, 2.0, 0.15, 0.7);
   
		if(texCol.a > 0.5)
			gl_FragColor = texCol + vec4(1.0, 1.0, 1.0, 1.0) * tmpBrightness;
		else
			gl_FragColor = vec4(0.0, 0.0, 0.0, 0.0);
}

